@@ -48,6 +48,10 @@ Class ProcessThread:
 Thread class for running subprocesses and posting the output to an
 L{OutputBuffer} via events.
 
+Class TaskThread:
+Thread class for running a callable. For optimal performance and resposiveness
+the callable should be a generator object. All results are directed to an
+L{OutputBuffer} through its AppendUpdate method.
 
 Requirements:
   * wxPython 2.8
@@ -57,8 +61,8 @@ Requirements:
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 54724 2008-07-20 04:58:16Z CJP $"
-__revision__ = "$Revision: 54724 $"
+__svnid__ = "$Id: outbuff.py 55987 2008-09-30 17:00:30Z CJP $"
+__revision__ = "$Revision: 55987 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -104,6 +108,10 @@ OPB_ALL_STYLES = (wx.stc.STC_STYLE_DEFAULT, wx.stc.STC_STYLE_CONTROLCHAR,
 edEVT_PROCESS_START = wx.NewEventType()
 EVT_PROCESS_START = wx.PyEventBinder(edEVT_PROCESS_START, 1)
 
+# Event for notifying that a task is starting to run
+edEVT_TASK_START = wx.NewEventType()
+EVT_TASK_START = wx.PyEventBinder(edEVT_TASK_START, 1)
+
 # Event for passing output data to buffer
 # GetValue returns the output text retrieved from the process
 edEVT_UPDATE_TEXT = wx.NewEventType()
@@ -114,9 +122,13 @@ EVT_UPDATE_TEXT = wx.PyEventBinder(edEVT_UPDATE_TEXT, 1)
 edEVT_PROCESS_EXIT = wx.NewEventType()
 EVT_PROCESS_EXIT = wx.PyEventBinder(edEVT_PROCESS_EXIT, 1)
 
+# Event to notify that a process has completed
+edEVT_TASK_COMPLETE = wx.NewEventType()
+EVT_TASK_COMPLETE = wx.PyEventBinder(edEVT_TASK_COMPLETE, 1)
+
 class OutputBufferEvent(wx.PyCommandEvent):
     """Event for data transfer and signaling actions in the L{OutputBuffer}"""
-    def __init__(self, etype, eid, value=''):
+    def __init__(self, etype, eid=wx.ID_ANY, value=''):
         """Creates the event object"""
         wx.PyCommandEvent.__init__(self, etype, eid)
         self._value = value
@@ -149,6 +161,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self._updating = threading.Condition(self._mutex)
         self._updates = list()
         self._timer = wx.Timer(self)
+        self._line_buffer = -1                
         self._colors = dict(defaultb=(255, 255, 255), defaultf=(0, 0, 0),
                             errorb=(255, 255, 255), errorf=(255, 0, 0),
                             infob=(255, 255, 255), infof=(0, 0, 255),
@@ -203,6 +216,7 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         self._updates = self._updates[ind:]
         self.ApplyStyles(start, txt)
         self.SetReadOnly(True)
+        self.RefreshBufferedLines()
         self._updating.release()
 
     def __SetupStyles(self, font=None):
@@ -368,6 +382,24 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         else:
             pass
 
+    def RefreshBufferedLines(self):
+        """Refresh and readjust the lines in the buffer to fit the current
+        line buffering limits.
+        @poscondition: Oldest lines are removed until we are back within the
+                       buffer limit bounds.
+
+        """
+        if self._line_buffer < 0:
+            return
+
+        while self.GetLineCount() > self._line_buffer:
+            self.SetCurrentPos(0)
+            self.SetReadOnly(False)
+            self.LineDelete()
+            self.SetReadOnly(True)
+
+        self.SetCurrentPos(self.GetLength())
+
     def SetDefaultColor(self, fore=None, back=None):
         """Set the colors for the default text style
         @keyword fore: Foreground Color
@@ -436,6 +468,14 @@ class OutputBuffer(wx.stc.StyledTextCtrl):
         for style in OPB_ALL_STYLES:
             self.StyleSetFont(style, font)
 
+    def SetLineBuffering(self, num):
+        """Set how many lines the buffer should keep for display.
+        @param num: int (-1 == unlimited)
+
+        """
+        self._line_buffer = num
+        self.RefreshBufferedLines()
+
     def SetText(self, text):
         """Set the text that is shown in the buffer
         @param text: text string to set as buffers current value
@@ -568,6 +608,9 @@ class ProcessThread(threading.Thread):
         self._cmd = dict(cmd=command, file=fname, args=args)
         self._env = env
 
+        # Setup
+        self.setDaemon(True)
+
     def __DoOneRead(self):
         """Read one line of output and post results.
         @param proc: process to read from
@@ -642,14 +685,35 @@ class ProcessThread(threading.Thread):
             return
 
         if wx.Platform != '__WXMSW__':
+            # Close output pipe(s)
             try:
-                self._proc.stdout.close()
+                try:
+                    self._proc.stdout.close()
+                except Exception, msg:
+                    pass
+            finally:
                 self._proc.stdout = None
-                os.kill(pid, signal.SIGKILL)
-            except OSError:
-                return
 
-            os.waitpid(pid, os.WNOHANG)
+            # Try to kill the group
+            try:
+                pgid = os.getpgid(pid)
+                os.killpg(pgid, signal.SIGKILL)
+            except OSError, msg:
+                pass
+
+            # If still alive shoot it again
+            if self._proc.poll() != None:
+                try:
+                    os.kill(-pid, signal.SIGKILL)
+                except OSError, msg:
+                    pass
+
+            # Try and wait for it to cleanup
+            try:
+                os.waitpid(-pid, os.WNOHANG)
+            except OSError, msg:
+                pass
+
         else:
             # 1 == PROCESS_TERMINATE
             handle = ctypes.windll.kernel32.OpenProcess(1, False, pid)
@@ -673,7 +737,13 @@ class ProcessThread(threading.Thread):
                                                        self._cmd['args']]])
 
         use_shell = not subprocess.mswindows
+        if use_shell:
+            preexec_fn = os.setsid
+        else:
+            preexec_fn = None
+
         self._proc = subprocess.Popen(command.strip(), stdout=subprocess.PIPE,
+                                      preexec_fn=preexec_fn,
                                       stderr=subprocess.STDOUT, shell=use_shell,
                                       cwd=self._cwd, env=self._env)
 
@@ -733,3 +803,46 @@ class ProcessThread(threading.Thread):
 
         """
         self._cmd['file'] = fname
+
+#-----------------------------------------------------------------------------#
+
+class TaskThread(threading.Thread):
+    """Run a task in its own thread."""
+    def __init__(self, parent, task, *args, **kwargs):
+        """Initialize the TaskThread. All *args and **kwargs are passed
+        to the task.
+
+        @param parent: Parent Window/EventHandler to recieve the events
+                       generated by the process.
+        @param task: callable should be a generator object and must be iterable
+
+        """
+        threading.Thread.__init__(self)
+
+        # Attributes
+        self.cancel = False         # Abort task
+        self._parent = parent       # Parent Window/Event Handler
+        self.task = task            # Task method to run
+        self._args = args
+        self._kwargs = kwargs
+
+    def run(self):
+        """Start running the task"""
+        # Notify that task is begining
+        evt = OutputBufferEvent(edEVT_TASK_START, self._parent.GetId())
+        wx.PostEvent(self._parent, evt)
+        time.sleep(.5) # Give the event a chance to be processed
+
+        # Run the task and post the results
+        for result in self.task(*self._args, **self._kwargs):
+            self._parent.AppendUpdate(result)
+            if self.cancel:
+                break
+
+        # Notify that the task is finished
+        evt = OutputBufferEvent(edEVT_TASK_COMPLETE, self._parent.GetId())
+        wx.PostEvent(self._parent, evt)
+
+    def Cancel(self):
+        """Cancel the running task"""
+        self.cancel = True
