@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 54634 2008-07-15 02:19:44Z CJP $"
-__revision__ = "$Revision: 54634 $"
+__svnid__ = "$Id: ed_main.py 56027 2008-10-02 02:59:14Z CJP $"
+__revision__ = "$Revision: 56027 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -44,6 +44,7 @@ import generator
 import plugin
 import perspective as viewmgr
 import iface
+import eclib.encdlg as encdlg
 
 # Function Aliases
 _ = wx.GetTranslation
@@ -68,7 +69,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         self._mgr = wx.aui.AuiManager(flags=wx.aui.AUI_MGR_DEFAULT | \
                                       wx.aui.AUI_MGR_TRANSPARENT_DRAG | \
-                                      wx.aui.AUI_MGR_TRANSPARENT_HINT)
+                                      wx.aui.AUI_MGR_TRANSPARENT_HINT |
+                                      wx.aui.AUI_MGR_ALLOW_ACTIVE_PANE)
         self._mgr.SetManagedWindow(self)
         viewmgr.PerspectiveManager.__init__(self, self._mgr, \
                                             CONFIG['CACHE_DIR'])
@@ -148,6 +150,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_SAVEAS, self.OnSaveAs),
                                        (ID_SAVEALL, self.OnSave),
                                        (ID_REVERT_FILE, self.DispatchToControl),
+                                       (ID_RELOAD_ENC, self.OnReloadWithEnc),
                                        (ID_SAVE_PROFILE, self.OnSaveProfile),
                                        (ID_LOAD_PROFILE, self.OnLoadProfile),
                                        (ID_EXIT, wx.GetApp().OnExit),
@@ -156,10 +159,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_PRINT_SU, self.OnPrint),
 
                                        # Edit Menu
-                                       (ID_FIND,
-                                        self.nb.FindService.OnShowFindDlg),
-                                       (ID_FIND_REPLACE,
-                                        self.nb.FindService.OnShowFindDlg),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -196,6 +195,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Update UI Handlers
         self._handlers['ui'].extend([# File Menu
                                      (ID_REVERT_FILE, self.OnUpdateFileUI),
+                                     (ID_RELOAD_ENC, self.OnUpdateFileUI),
                                      # Edit Menu
                                      (ID_COPY, self.OnUpdateClipboardUI),
                                      (ID_CUT, self.OnUpdateClipboardUI),
@@ -216,21 +216,17 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_AUTOINDENT, self.OnUpdateSettingsUI),
                                      (ID_SYNTAX, self.OnUpdateSettingsUI),
                                      (ID_FOLDING, self.OnUpdateSettingsUI),
-                                     (ID_BRACKETHL, self.OnUpdateSettingsUI),
-                                     # View Menu
-                                     (ID_ZOOM_NORMAL, self.OnUpdateViewUI),
-                                     (ID_ZOOM_IN, self.OnUpdateViewUI),
-                                     (ID_ZOOM_OUT, self.OnUpdateViewUI),
-                                     (ID_GOTO_MBRACE, self.OnUpdateViewUI),
-                                     (ID_HLCARET_LINE, self.OnUpdateViewUI),
-                                     (ID_SHOW_SB, self.OnUpdateViewUI),
-                                     (ID_VIEW_TOOL, self.OnUpdateViewUI),
-                                     (ID_SHOW_WS, self.OnUpdateViewUI),
-                                     (ID_SHOW_EDGE, self.OnUpdateViewUI),
-                                     (ID_SHOW_EOL, self.OnUpdateViewUI),
-                                     (ID_SHOW_LN, self.OnUpdateViewUI),
-                                     (ID_INDENT_GUIDES, self.OnUpdateViewUI)
-                                    ])
+                                     (ID_BRACKETHL, self.OnUpdateSettingsUI)])
+
+        # View Menu
+        self._handlers['ui'].extend([(m_id, self.OnUpdateViewUI)
+                                      for m_id in [ID_ZOOM_NORMAL, ID_ZOOM_IN,
+                                                   ID_ZOOM_OUT, ID_GOTO_MBRACE,
+                                                   ID_HLCARET_LINE, ID_SHOW_SB,
+                                                   ID_VIEW_TOOL, ID_SHOW_WS,
+                                                   ID_SHOW_EDGE, ID_SHOW_EOL,
+                                                   ID_SHOW_LN, ID_INDENT_GUIDES,
+                                                   ]])
 
         # Lexer Menu
         self._handlers['ui'].extend([(l_id, self.OnUpdateLexerUI)
@@ -248,11 +244,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.Bind(ed_event.EVT_STATUS, self.OnStatus)
 
         # Find Dialog
-        self.Bind(wx.EVT_FIND, self.nb.FindService.OnFind)
-        self.Bind(wx.EVT_FIND_NEXT, self.nb.FindService.OnFind)
-        self.Bind(wx.EVT_FIND_REPLACE, self.nb.FindService.OnFind)
-        self.Bind(wx.EVT_FIND_REPLACE_ALL, self.nb.FindService.OnFind)
-        self.Bind(wx.EVT_FIND_CLOSE, self.nb.FindService.OnFindClose)
+        self._handlers['menu'].extend(self.nb.GetMenuHandlers())
+        self._handlers['ui'].extend(self.nb.GetUiHandlers())
 
         #---- End other event actions ----#
 
@@ -291,7 +284,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         app = wx.GetApp()
         if evt.GetActive():
+
+            # Slow the update interval to reduce overhead
+            wx.UpdateUIEvent.SetUpdateInterval(160)
+            wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
             self.SetExtraStyle(wx.WS_EX_PROCESS_UI_UPDATES)
+
             for handler in self._handlers['menu']:
                 app.AddHandlerForID(*handler)
 
@@ -300,17 +298,17 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             self.SetExtraStyle(0)
 
-            # Hack set update ui events back to proccess all here in case
+            # HACK set update ui events back to proccess all here in case
             # opened dialog needs them. Not sure why this is necessary but it
             # is the only solution I could find to fix the external find
             # dialogs so that there buttons become enabled when typing in the
             # text control.
             #
             # If the windows that took the active position is another mainwindow
-            # it will set the events back to UPDATE_UI_PROCESS_SPECIFED to
+            # it will set the events back to UPDATE_UI_PROCESS_SPECIFIED to
             # prevent all the toolbars/menu items of each window from updating
             # when they dont need to.
-            wx.UpdateUIEvent().SetMode(wx.UPDATE_UI_PROCESS_ALL)
+            wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_ALL)
             for handler in self._handlers['menu']:
                 app.RemoveHandlerForID(handler[0])
 
@@ -373,6 +371,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             fdir = self.GetNotebook().GetCurrentCtrl().GetFileName()
             if len(fdir):
                 fdir = os.path.dirname(fdir)
+            elif not hasattr(sys, 'frozen'):
+                fdir = os.curdir
 
             dlg = wx.FileDialog(self, _("Choose a File"), fdir, "",
                                 ''.join(syntax.GenFileFilters()),
@@ -394,6 +394,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self.LOG("[ed_main][info] CMD Open File: %s" % fname)
             self.nb.OpenPage(util.GetPathName(fname),
                              util.GetFileName(fname), quiet=True)
+            self.Raise()
+
+    def GetCommandbar(self):
+        """Get this windows command bar
+        @return: ed_cmdbar.CommandBar
+
+        """
+        return self._cmdbar
 
     def GetFrameManager(self):
         """Returns the manager for this frame
@@ -407,7 +415,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @return: reference to L{extern.flatnotebook.FlatNotebook} instance
 
         """
-        return self.nb
+        return getattr(self, 'nb', None)
 
     def GetShelf(self):
         """Get this windows Shelf
@@ -533,11 +541,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 result = ctrl[1].SaveFile(fpath)
                 if result:
                     self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
-                    if e_id == ID_SAVEALL:
-                        if ctrl[2] != self.nb.GetSelection():
-                            self.nb.SetPageText(ctrl[2], fname)
-                        else:
-                            self.nb.OnUpdatePageText(None)
                 else:
                     err = ctrl[1].GetDocument().GetLastError()
                     self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
@@ -548,7 +551,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 if ret_val:
                     self.AddFileToHistory(ctrl[1].GetFileName())
 
-    def OnSaveAs(self, evt, title='', page=None):
+    def OnSaveAs(self, evt, title=u'', page=None):
         """Save File Using a new/different name
         @param evt: Event fired that called this handler
         @type evt: wxMenuEvent
@@ -559,6 +562,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             ctrl = self.nb.GetCurrentCtrl()
 
+        if title == u'':
+            title = os.path.split(ctrl.GetFileName())[1]
+
         dlg = wx.FileDialog(self, _("Choose a Save Location"),
                             os.path.dirname(ctrl.GetFileName()),
                             title.lstrip("*"),
@@ -655,8 +661,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         e_id = evt.GetId()
         printer = ed_print.EdPrinter(self, self.nb.GetCurrentCtrl)
-        printer.SetColourMode(_PGET('PRINT_MODE', "str").\
-                              replace(u'/', u'_').lower())
+        printer.SetColourMode(_PGET('PRINT_MODE'))
         if e_id == ID_PRINT:
             printer.Print()
         elif e_id == ID_PRINT_PRE:
@@ -942,6 +947,37 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Skip()
         return
 
+    def OnReloadWithEnc(self, evt):
+        """Reload the current file with a specified encoding
+        @param evt: wx.MenuEvent
+
+        """
+        if evt.GetId() == ID_RELOAD_ENC:
+            ctrl = self.nb.GetCurrentCtrl()
+            doc = ctrl.GetDocument()
+            cenc = doc.GetEncoding()
+            dlg = encdlg.EncodingDialog(self.GetNotebook(),
+                                        msg=_("Select an encoding to reload the file with"),
+                                        title=_("Reload with Encoding"),
+                                        default=cenc)
+            bmp = wx.ArtProvider.GetBitmap(str(ID_DOCPROP), wx.ART_OTHER)
+            if bmp.IsOk():
+                dlg.SetBitmap(bmp)
+            dlg.CenterOnParent()
+
+            if dlg.ShowModal() == wx.ID_OK:
+                nenc = dlg.GetEncoding()
+                doc.SetEncoding(nenc)
+                success = ctrl.ReloadFile()[0]
+                if not success:
+                    msg= _("Failed to reload the file with: %(encoding)s") % dict(encoding=nenc)
+                    wx.MessageBox(msg, style=wx.OK|wx.ICON_ERROR)
+                    doc.SetEncoding(cenc)
+                    ctrl.ReloadFile()
+            dlg.Destroy()
+        else:
+            evt.Skip()
+
     # Menu Update Handlers
     def OnUpdateFileUI(self, evt):
         """Update filemenu items
@@ -952,12 +988,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        # Slow the update interval to reduce overhead
-        evt.SetUpdateInterval(160)
+        ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_REVERT_FILE:
-            ctrl = self.nb.GetCurrentCtrl()
             evt.Enable(ctrl.GetModify())
+        elif e_id == ID_RELOAD_ENC:
+            evt.Enable(len(ctrl.GetFileName()))
         else:
             evt.Skip()
 
@@ -970,9 +1005,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        # Slow the update interval to reduce overhead
-        evt.SetUpdateInterval(160)
         ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_UNDO:
             evt.Enable(ctrl.CanUndo())
@@ -994,8 +1026,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        evt.SetUpdateInterval(300)
         ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_USE_SOFTTABS:
             evt.Check(not bool(ctrl.GetUseTabs()))
@@ -1017,8 +1047,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        evt.SetUpdateInterval(400)
         if e_id in syntax.SyntaxIds():
             lang = self.nb.GetCurrentCtrl().GetLangId()
             evt.Check(lang == evt.GetId())
@@ -1034,8 +1062,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        evt.SetUpdateInterval(300)
         ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_AUTOCOMP:
             evt.Check(ctrl.GetAutoComplete())
@@ -1059,8 +1085,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             return
 
         e_id = evt.GetId()
-        evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        evt.SetUpdateInterval(300)
         ctrl = self.nb.GetCurrentCtrl()
         zoom = ctrl.GetZoom()
         if e_id == ID_ZOOM_NORMAL:
@@ -1097,15 +1121,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         e_id = evt.GetId()
-        if e_id == ID_QUICK_FIND:
-            self._cmdbar.Show(ed_cmdbar.ID_SEARCH_CTRL)
-        elif e_id == ID_GOTO_LINE:
-            self._cmdbar.Show(ed_cmdbar.ID_LINE_CTRL)
-        elif e_id == ID_COMMAND:
-            self._cmdbar.Show(ed_cmdbar.ID_CMD_CTRL)
+        ctrld = { ID_QUICK_FIND : ed_cmdbar.ID_SEARCH_CTRL,
+                  ID_GOTO_LINE : ed_cmdbar.ID_LINE_CTRL,
+                  ID_COMMAND : ed_cmdbar.ID_CMD_CTRL }
+        if e_id in ctrld:
+            self.ShowCommandCtrl(ctrld[e_id])
         else:
             evt.Skip()
-        self.sizer.Layout()
 
     def OnHelp(self, evt):
         """Handles help related menu events
@@ -1114,7 +1136,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         import webbrowser
-
         e_id = evt.GetId()
         if e_id == ID_HOMEPAGE:
             page = HOME_PAGE
@@ -1138,12 +1159,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         except:
             self.PushStatusText(_("Error: Unable to open %s") % page, SB_INFO)
 
-    def ShowCommandCtrl(self):
+    def ShowCommandCtrl(self, ctrl_id):
         """Open the Commandbar in command mode.
-        @todo: check if this is necessary
+        @param ctrl_id: control id to show
 
         """
-        self._cmdbar.Show(ed_cmdbar.ID_CMD_CTRL)
+        self._cmdbar.Show(ctrl_id)
         self.sizer.Layout()
 
     def ModifySave(self):
