@@ -20,8 +20,8 @@ in the notebook see ed_stc.py
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 54780 2008-07-24 02:56:08Z CJP $"
-__revision__ = "$Revision: 54780 $"
+__svnid__ = "$Id: ed_pages.py 56031 2008-10-02 03:22:10Z CJP $"
+__revision__ = "$Revision: 56031 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -41,6 +41,8 @@ import doctools
 import ed_msg
 import ed_txt
 import ed_mdlg
+import ed_menu
+import eclib.encdlg as encdlg
 from extern import flatnotebook as FNB
 
 #--------------------------------------------------------------------------#
@@ -71,7 +73,7 @@ class EdPages(FNB.FlatNotebook):
 
         # Notebook attributes
         self.LOG = wx.GetApp().GetLog()
-        self.FindService = ed_search.TextFinder(self, self.GetCurrentCtrl)
+        self._searchctrl = ed_search.SearchController(self, self.GetCurrentCtrl)
         self.DocMgr = doctools.DocPositionMgr(ed_glob.CONFIG['CACHE_DIR'] + \
                                               os.sep + u'positions')
         self.pg_num = -1              # Track new pages (aka untitled docs)
@@ -79,6 +81,7 @@ class EdPages(FNB.FlatNotebook):
         self.frame = self.GetTopLevelParent() # MainWindow
         self._index = dict()          # image list index
         self._ses_load = False
+        self._menu = None
 
         # Set Additional Style Parameters
         self.SetNonActiveTabTextColour(wx.Colour(102, 102, 102))
@@ -98,7 +101,11 @@ class EdPages(FNB.FlatNotebook):
         self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CLOSED, self.OnPageClosed)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnUpdatePageText)
         self._pages.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
+        self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CONTEXT_MENU, self.OnTabMenu)
+        self.Bind(wx.EVT_MENU, self.OnCopyTabPath, id=ed_glob.ID_COPY_PATH)
         self.Bind(wx.EVT_IDLE, self.OnIdle)
+
+        # Message handlers
         ed_msg.Subscribe(self.OnThemeChanged, ed_msg.EDMSG_THEME_CHANGED)
         ed_msg.Subscribe(self.OnThemeChanged, ed_msg.EDMSG_THEME_NOTEBOOK)
 
@@ -108,6 +115,57 @@ class EdPages(FNB.FlatNotebook):
     #---- End Init ----#
 
     #---- Function Definitions ----#
+    def _HandleEncodingError(self, control):
+        """Handle trying to reload the file the file with a different encoding
+        Until it suceeds or gives up.
+        @param control: stc
+        @return: bool
+
+        """
+        # Loop while the load fails prompting to try a new encoding
+        tried = None
+        fname = control.GetFileName().strip(os.sep)
+        fname = fname.split(os.sep)[-1]
+        while True:
+            doc = control.GetDocument()
+            doc.ClearLastError()
+            if tried is None:
+                enc = doc.GetEncoding()
+                if enc is None:
+                    enc = ed_txt.DEFAULT_ENCODING
+            else:
+                enc = tried
+
+            msg = _("The correct encoding of '%s' could not be determined.\n\n"
+                    "Choose an encoding and select Ok to open the file with the chosen encoding.\n"
+                    "Click Cancel to abort opening the file") % fname
+            dlg = encdlg.EncodingDialog(self, msg=msg,
+                                        title=_("Choose an Encoding"),
+                                        default=enc)
+            bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DOCPROP),
+                                           wx.ART_OTHER)
+            if bmp.IsOk():
+                dlg.SetBitmap(bmp)
+            dlg.CenterOnParent()
+            result = dlg.ShowModal()
+            enc = dlg.GetEncoding()
+            dlg.Destroy()
+
+            # Don't want to open it in another encoding
+            if result == wx.ID_CANCEL:
+                return False
+            else:
+                control.SetEncoding(enc)
+                tried = enc
+                ok = control.LoadFile(control.GetFileName())
+                if ok:
+                    return True
+                else:
+                    # Artifically add a short pause, because if its not there
+                    # the dialog will be shown again so fast it wont seem
+                    # like reloading the file was even tried.
+                    wx.Sleep(1)
+
     def _NeedOpen(self, path):
         """Check if a file needs to be opened. If the file is already open in
         the notebook a dialog will be opened to ask if the user wants to reopen
@@ -160,6 +218,24 @@ class EdPages(FNB.FlatNotebook):
                 rlist.append(fname)
         return rlist
 
+    def GetMenuHandlers(self):
+        """Get the (id, evt_handler) tuples that this window should
+        handle.
+        @return: list of tuples
+
+        """
+        rlist = [(ed_glob.ID_FIND, self._searchctrl.OnShowFindDlg),
+                 (ed_glob.ID_FIND_REPLACE, self._searchctrl.OnShowFindDlg),
+                 (ed_glob.ID_FIND_NEXT, self._searchctrl.OnFind)]
+        return rlist
+
+    def GetUiHandlers(self):
+        """Get the update ui handlers that this window supplies
+        @return: list of tuples
+
+        """
+        return [(ed_glob.ID_FIND_NEXT, self._searchctrl.OnUpdateFindUI),]
+
     def LoadSessionFiles(self):
         """Load files from saved session data in profile
         @postcondition: Files saved from previous session are
@@ -188,6 +264,7 @@ class EdPages(FNB.FlatNotebook):
         self.GetTopLevelParent().Freeze()
         self.pg_num += 1
         self.control = ed_stc.EditraStc(self, wx.ID_ANY)
+        self.control.SetEncoding(Profile_Get('ENCODING'))
         self.LOG("[ed_pages][evt] New Page Created ID: %d" % self.control.GetId())
         self.AddPage(self.control, u"Untitled - %d" % self.pg_num)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
@@ -199,6 +276,40 @@ class EdPages(FNB.FlatNotebook):
         self.control.FindLexer(ext_lst[0])
         self.GetTopLevelParent().Thaw()
 
+    def OnCopyTabPath(self, evt):
+        """Copy the path of the selected tab to the clipboard.
+        @param evt: wxMenuEvent
+
+        """
+        if evt.GetId() == ed_glob.ID_COPY_PATH:
+            path = self.control.GetFileName()
+            if path is not None:
+                util.SetClipboardText(path)
+        else:
+            evt.Skip()
+
+    def OnTabMenu(self, evt):
+        """Show the tab context menu"""
+        # Destroy any existing menu
+        if self._menu is not None:
+            self._menu.Destroy()
+            self._menu = None
+        cidx = self.GetSelection()
+        ptxt = self.GetPageText(cidx)
+
+        # Construct the menu
+        self._menu = ed_menu.EdMenu()
+        self._menu.Append(ed_glob.ID_NEW, _("New Tab"))
+        self._menu.AppendSeparator()
+        self._menu.Append(ed_glob.ID_SAVE, _("Save \"%s\"") % ptxt)
+        self._menu.Append(ed_glob.ID_CLOSE, _("Close \"%s\"") % ptxt)
+        self._menu.Append(ed_glob.ID_CLOSEALL, _("Close All"))
+        self._menu.AppendSeparator()
+        self._menu.Append(ed_glob.ID_COPY_PATH, _("Copy Full Path"))
+        #self._menu.AppendSeparator()
+        
+        self.PopupMenu(self._menu)
+
     def OnThemeChanged(self, msg):
         """Update icons when the theme has changed
         @param msg: Message Object
@@ -270,29 +381,16 @@ class EdPages(FNB.FlatNotebook):
             result = True
 
         # Check if there was encoding errors
+        if not result and not self._ses_load:
+            result = self._HandleEncodingError(control)
+
+        # Cleanup after errors
         if not result:
-            doc = control.GetDocument()
-            doc.ClearLastError()
-            enc = doc.GetEncoding()
-            enc1 = doc.GetMagic()
-            if enc1 is None:
-                enc1 = ed_txt.DEFAULT_ENCODING
-
-            if not self._ses_load:
-                errmap = dict(encoding1=enc1, encoding2=enc)
-                dlg = wx.MessageDialog(self,
-                   _("The document could not be decoded with %(encoding1)s."
-                     "\n\nWould you like to open it as %(encoding2)s instead?")
-                   % errmap, _("Encoding Error"),
-                   style=wx.YES_NO|wx.ICON_WARNING)
-                dlg.CenterOnParent()
-                result = dlg.ShowModal()
-
-        # Don't want to open it in another encoding
-        if result == wx.ID_NO or not result:
             if new_pg:
+                # We created a new one so destroy it
                 control.Destroy()
             else:
+                # We where using an existing buffer so reset it
                 control.SetText('')
                 control.SetDocument(ed_txt.EdFile())
                 control.SetSavePoint()
@@ -306,7 +404,6 @@ class EdPages(FNB.FlatNotebook):
             self.control = control
 
         # Setup Document
-        self.control.SetModTime(util.GetFileModTime(path2file))
         self.control.FindLexer()
         self.control.CheckEOL()
         self.control.EmptyUndoBuffer()
@@ -341,8 +438,6 @@ class EdPages(FNB.FlatNotebook):
         if current_page < 0:
             return current_page
 
-        self.LOG("[ed_pages][info] Current Page = %d" % current_page)
-
         control = self.GetPage(current_page)
         control.SetFocus()
         self.control = control
@@ -675,14 +770,28 @@ class EdPages(FNB.FlatNotebook):
 
         """
         try:
-            pg_num = self.GetSelection()
-            title = self.GetPageText(pg_num)
-            if self.control.GetModify():
-                title = u"*" + title
-            if title != FNB.FlatNotebook.GetPageText(self, pg_num):
-                self.SetPageText(pg_num, title)
-                ftitle = u"%s - file://%s" % (title, self.control.GetFileName())
-                self.frame.SetTitle(ftitle)
+            e_id = evt.GetId()
+            if self.control.GetId() == e_id:
+                pg_num = self.GetSelection()
+                title = self.GetPageText(pg_num)
+                if self.control.GetModify():
+                    title = u"*" + title
+
+                # Only Update if the text has changed
+                if title != FNB.FlatNotebook.GetPageText(self, pg_num):
+                    self.SetPageText(pg_num, title)
+                    ftitle = u"%s - file://%s" % (title, self.control.GetFileName())
+                    self.frame.SetTitle(ftitle)
+            else:
+                # A background page has changed
+                for page in range(self.GetPageCount()):
+                    control = self.GetPage(page)
+                    if control.GetId() == e_id:
+                        title = self.GetPageText(page)
+                        if control.GetModify():
+                            title = u"*" + title
+                        if title != FNB.FlatNotebook.GetPageText(self, page):
+                            self.SetPageText(page, title)
         except wx.PyDeadObjectError:
             pass
 
