@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 54784 2008-07-25 13:16:53Z CJP $"
-__revision__ = "$Revision: 54784 $"
+__svnid__ = "$Id: ed_stc.py 55996 2008-10-01 03:37:14Z CJP $"
+__revision__ = "$Revision: 55996 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -54,6 +54,7 @@ SPACECHARS = " \t\r\n"
 NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
            "0123456789_./\?[]{}<>!@#$%^&*():=-+\"';,"
 #-------------------------------------------------------------------------#
+
 class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     """Defines a styled text control for editing text
     @summary: Subclass of wx.stc.StyledTextCtrl and L{ed_style.StyleMgr}.
@@ -101,9 +102,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # Command/Settings Attributes
         self._config = dict(autocomp=_PGET('AUTO_COMP'),
                             autoindent=_PGET('AUTO_INDENT'),
-                            brackethl=_PGET("BRACKETHL"),
+                            brackethl=_PGET('BRACKETHL'),
                             folding=_PGET('CODE_FOLD'),
-                            highlight=_PGET("SYNTAX"))
+                            highlight=_PGET('SYNTAX'))
 
         # Code Related Objects
         self._code = dict(compsvc=autocomp.AutoCompService(self),
@@ -149,12 +150,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Context Menu Events
         self.Bind(wx.EVT_CONTEXT_MENU, lambda evt: self.PopupMenu(self._menu))
-        self.Bind(wx.EVT_MENU, lambda evt: self.Undo(), id=wx.ID_UNDO)
-        self.Bind(wx.EVT_MENU, lambda evt: self.Redo(), id=wx.ID_REDO)
-        self.Bind(wx.EVT_MENU, lambda evt: self.Cut(), id=wx.ID_CUT)
-        self.Bind(wx.EVT_MENU, lambda evt: self.Copy(), id=wx.ID_COPY)
-        self.Bind(wx.EVT_MENU, lambda evt: self.Paste(), id=wx.ID_PASTE)
-        self.Bind(wx.EVT_MENU, lambda evt: self.SelectAll(), id=wx.ID_SELECTALL)
 
        #---- End Init ----#
 
@@ -931,6 +926,12 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type evt: wx.stc.StyledTextEvent
 
         """
+        # Adjust line number margin width to expand as needed when line
+        # number width over fills the area.
+        lines = self.GetLineCount()
+        mwidth = self.GetTextExtent(str(lines))[0]
+        self.SetMarginWidth(NUM_MARGIN, max(30, mwidth + 8))
+
         wx.PostEvent(self.GetParent(), evt)
 
     def OnUpdateUI(self, evt):
@@ -1441,13 +1442,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.file.SetPath(path)
 
     def SetFocus(self):
-        """Set the focus to the window"""
+        """Set the focus to this control
+        @note: overriden as a hack for msw
+
+        """
         wx.stc.StyledTextCtrl.SetFocus(self)
-        # HACK fix issue where setting the focus requires a
-        # click from the mouse under msw. ?wxBug?
         if wx.Platform == '__WXMSW__':
-            evt = wx.FocusEvent(wx.wxEVT_SET_FOCUS, self.GetId())
-            wx.PostEvent(self, evt)
+            wx.PostEvent(self, wx.FocusEvent(wx.wxEVT_SET_FOCUS, self.GetId()))
 
     def SetLexer(self, lexer):
         """Set the buffers lexer
@@ -1471,7 +1472,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def SetModTime(self, modtime):
         """Set the value of the files last modtime"""
-        self.file.SetModtime(modtime)
+        self.file.SetModTime(modtime)
 
     def SetViEmulationMode(self, use_vi):
         """Activate/Deactivate Vi eumulation mode
@@ -1787,6 +1788,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 return False, msg
             else:
                 self.GotoPos(cpos)
+                ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENED, self.GetFileName())
                 return True, ''
         else:
             self.LOG("[ed_stc][err] %s does not exists, cant reload." % cfile)
@@ -1840,7 +1842,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if result:
             self.SetSavePoint()
             self.SetModTime(util.GetFileModTime(path))
-            self.OnModified(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_MODIFIED))
+            self.OnModified(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_MODIFIED,
+                                                   self.GetId()))
             self.SetFileName(path)
 
         wx.CallAfter(ed_msg.PostMessage,
@@ -1960,7 +1963,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self._code['indenter'] = indenter
 
         # Notify that lexer has changed
-        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_LEXER)
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_LEXER,
+                           (self.GetFileName(), self.GetLangId()))
         return True
 
     def SetKeyWords(self, kw_lst):
@@ -2127,12 +2131,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 def MakeMenu():
     """Make the buffers context menu"""
     menu = ed_menu.EdMenu()
-    menu.Append(wx.ID_UNDO, _("Undo"))
-    menu.Append(wx.ID_REDO, _("Redo"))
+    menu.Append(ed_glob.ID_UNDO, _("Undo"))
+    menu.Append(ed_glob.ID_REDO, _("Redo"))
     menu.AppendSeparator()
-    menu.Append(wx.ID_CUT, _("Cut"))
-    menu.Append(wx.ID_COPY, _("Copy"))
-    menu.Append(wx.ID_PASTE, _("Paste"))
+    menu.Append(ed_glob.ID_CUT, _("Cut"))
+    menu.Append(ed_glob.ID_COPY, _("Copy"))
+    menu.Append(ed_glob.ID_PASTE, _("Paste"))
     menu.AppendSeparator()
-    menu.Append(wx.ID_SELECTALL, _("Select All"))
+    menu.Append(ed_glob.ID_TO_UPPER, _("To Uppercase"))
+    menu.Append(ed_glob.ID_TO_LOWER, _("To Lowercase"))
+    menu.AppendSeparator()
+    menu.Append(ed_glob.ID_SELECTALL, _("Select All"))
     return menu
