@@ -16,13 +16,15 @@ can be installed as single file instead of dozens of individual image files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 52855 2008-03-27 14:53:06Z CJP $"
-__revision__ = "$Revision: 52855 $"
+__svnid__ = "$Id: ed_theme.py 56026 2008-10-02 02:58:38Z CJP $"
+__revision__ = "$Revision: 56026 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import os
 import wx
+
+# Local Imports
 import ed_glob
 import util
 import plugin
@@ -79,6 +81,18 @@ class ThemeI(plugin.Interface):
         """
         return wx.NullBitmap
 
+    def GetOtherBitmap(self, bmp_id):
+        """Get the bitmap from the 'other' icon resources. Valid id's are
+        identified by a mapping in the ART dictionary.
+        
+        If this theme does not have a resource to provide for this
+        object return a wx.NullBitmap.
+
+        @return: wx.Bitmap
+
+        """
+        return wx.NullBitmap
+
     def GetToolbarBitmap(self, bmp_id):
         """Get the toolbar bitmap associated with the object id. The
         toolbar icons must be returned as a 32x32 pixel bitmap any
@@ -132,6 +146,8 @@ class BitmapProvider(plugin.Plugin):
             bmp = theme.GetToolbarBitmap(bmp_id)
         elif client == wx.ART_MENU:
             bmp = theme.GetMenuBitmap(bmp_id)
+        elif client == wx.ART_OTHER:
+            bmp = theme.GetOtherBitmap(bmp_id)
         else:
             pass
 
@@ -158,6 +174,12 @@ class BitmapProvider(plugin.Plugin):
         if prov is not None:
             if client == wx.ART_MENU:
                 bmp = prov.GetMenuBitmap(bmp_id)
+            elif client == wx.ART_OTHER:
+                # Backwards compatibility for older interface
+                if hasattr(prov, 'GetOtherBitmap'):
+                    bmp = prov.GetOtherBitmap(bmp_id)
+                else:
+                    bmp = wx.NullBitmap
             else:
                 bmp = prov.GetToolbarBitmap(bmp_id)
 
@@ -190,6 +212,7 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_FILE   : u'file.png',
         ed_glob.ID_FIND   : u'find.png',
         ed_glob.ID_FIND_REPLACE : u'findr.png',
+        ed_glob.ID_FIND_RESULTS : u'find.png',
         ed_glob.ID_FLOPPY : u'floppy.png',
         ed_glob.ID_FOLDER : u'folder.png',
         ed_glob.ID_FONT   : u'font.png',
@@ -198,6 +221,7 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_HTML_GEN : u'html_gen.png',
         ed_glob.ID_INDENT : u'indent.png',
         ed_glob.ID_KWHELPER : u'kw_help.png',
+        ed_glob.ID_LOGGER : u'log.png',
         ed_glob.ID_NEW    : u'new.png',
         ed_glob.ID_NEW_WINDOW: u'newwin.png',
         ed_glob.ID_NEXT_MARK : u'bmark_next.png',
@@ -209,11 +233,14 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_PREF    : u'pref.png',
         ed_glob.ID_PRINT   : u'print.png',
         ed_glob.ID_PRINT_PRE : u'printpre.png',
+        ed_glob.ID_PYSHELL : u'pyshell.png',
         ed_glob.ID_REDO    : u'redo.png',
+        ed_glob.ID_REFRESH : u'refresh.png',
         ed_glob.ID_RTF_GEN : u'rtf_gen.png',
         ed_glob.ID_SAVE    : u'save.png',
         ed_glob.ID_SAVEALL : u'saveall.png',
         ed_glob.ID_SAVEAS  : u'saveas.png',
+        ed_glob.ID_SELECTALL : u'selectall.png',
         ed_glob.ID_STOP    : u'stop.png',
         ed_glob.ID_STYLE_EDIT : u'style_edit.png',
         ed_glob.ID_TEX_GEN : u'tex_gen.png',
@@ -272,7 +299,11 @@ class TangoTheme(plugin.Plugin):
         @rtype: string
 
         """
-        clients = {wx.ART_MENU : u"menu", wx.ART_TOOLBAR : u"toolbar"}
+        clients = { wx.ART_MENU : u"menu",
+                    wx.ART_TOOLBAR : u"toolbar",
+                    wx.ART_OTHER : u"other" }
+
+        # Get the path
         if ed_glob.CONFIG['THEME_DIR'] == u'':
             theme = util.ResolvConfigDir(os.path.join("pixmaps", "theme"))
             ed_glob.CONFIG['THEME_DIR'] = theme
@@ -286,7 +317,6 @@ class TangoTheme(plugin.Plugin):
                                 clients.get(client, u"menu"))
 
         path += os.sep
-
         if os.path.exists(path):
             return path
         else:
@@ -335,13 +365,27 @@ class TangoTheme(plugin.Plugin):
 
         return wx.NullBitmap
 
+    def GetOtherBitmap(self, bmp_id):
+        """Get a other catagory bitmap.
+        @param bmp_id: Id of art resource
+
+        """
+        if bmp_id in ART:
+            path = self.__GetArtPath(wx.ART_OTHER, mime=False)
+            if path is not None:
+                path = path + ART[bmp_id]
+                if os.path.exists(path):
+                    return wx.Bitmap(path, wx.BITMAP_TYPE_PNG)
+
+        return wx.NullBitmap
+
     def GetToolbarBitmap(self, bmp_id):
         """Get a toolbar bitmap
         @param bmp_id: Id of bitmap to look for
         @return: wx.NullBitmap or a 32x32 bitmap
 
         """
-        if ART.has_key(bmp_id):
+        if bmp_id in ART:
             path = self.__GetArtPath(wx.ART_TOOLBAR, mime=False)
             if path is not None:
                 path = path + ART[bmp_id]
