@@ -60,8 +60,8 @@ memory is not likely to be very large.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: plugin.py 54026 2008-06-08 02:16:56Z CJP $"
-__revision__ = "$Revision: 54026 $"
+__svnid__ = "$Id: plugin.py 56042 2008-10-03 00:58:26Z CJP $"
+__revision__ = "$Revision: 56042 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -71,6 +71,7 @@ import wx
 
 # Editra Libraries
 import ed_glob
+from ed_txt import DecodeString
 import util
 from profiler import CalcVersionValue
 
@@ -421,12 +422,17 @@ class PluginManager(object):
         in path list
         @param path: path(s) to scan for extension points
         @type path: list of path strings
+        @todo: Figure out why decoding the path with getfilesystemencoding
+               fails on some systems.
 
         """
         if pkg_resources != None:
-            path = [ pname.encode(sys.getfilesystemencoding()) 
+            path = [ DecodeString(pname, sys.getfilesystemencoding())
                      for pname in path ]
-            env = pkg_resources.Environment(path)
+            try:
+                env = pkg_resources.Environment(path)
+            except UnicodeDecodeError, msg:
+                self.LOG("[pluginmgr][err] %s" % msg)
         else:
             self.LOG("[pluginmgr][warn] setup tools is not installed")
             env = dict()
